==> alfred_osint-0.2.3.dev0-py3-none-any.whl: alfred_osint/lang/en.py <==
# en.py
# English

encrypt1 = "Encrypting Key..."

title1 = "Many Thanks To Our Partners!"

disclamer = "     Desclaimer: Not All Sites And Or Proxys Are Garineteed To Work! \n     By Using You Take Full Account Of Your Actions"

targetusernames = "The Target Username(s): "

version = "Version"

config1 = "Config File Exsits: "
config2 = "Update File Exsits: "
config3 = "Folder Already Exsists: "
config4 = "Check For Updates? [Y/n]: ⤷ "
config5 = "Edit The Config? [Y/n]: ⤷ "
config6 = "What Do You Want To Change? ⤷ "
config7 = "Creating folder: "
config8 = "Folder already exists: "

configOption1 = "[1] Check for updates: "
configOption2 = "[2] Show tips: "
configOption3 = "[3] Site Download Path: "
configOption4 = "[4] Browser: "
configOption5 = "[5] Language: "
configOptionA = "[A] Clean Up Alfred. (This Removes Temporary Files)"
configOptionB = "[B] Developer Tools."

configOption1Message = "Ok! [checkforupdates] Is Set For Yes. Changing To No"
configOption2Message = "Ok! [showtips] Is Set For Yes. Changing To No"
configOption3Message = "New Path: ⤷ "
configOption4Message = """Types Supported:
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            please enter your language code
            language Supported:
                it = Italian
                en = English
                il = Hebrew
                es = Spanish
                fr = French
                ar = Arabic
                         """
configOptionAMessage = "Done!"
configOptionBMessage = "Welcome To The Developer Menu!"

configOption1Message2 = "Ok! [checkforupdates] Is Set For No. Changing To Yes"
configOption2Message2 = "Ok! [showtips] Is Set For No. Changing To Yes"
configOptionBMessage2 = "DONT Give The Following Keys To Anyone But A Alfred Developer."
configOptionBMessage3 = "privatekey: "
configOptionBMessage4 = "syscrypt: "

target = "Target: ⤷ "
browser = "Browser: "

file_not_found = "File not found: {filename}"
permission_denied = "Permission denied for {operation} on {path}"

note = "Note! "
path = "PATH: ⤷ "
warning1 = "Sites Many Not Allow Downloading Their Site Files. Use At Your Own Risk."
warning2 = " Using The Webscraper Is Pretty Slow."
warning3 = " This Is Your First Launch :D You Might Need To Restart Alfred To Use All The Modules"
warning4 = " You Are Using A Prerelease Of Alfred!"

confirm1 = "Want To Download Images/Videos? [Y/n] ⤷ "
confirm2 = "Run Again?: [Y/n] ⤷ "

prompt1 = "Enter Site Again: ⤷ "
prompt2 = "Kindly Report Any Bugs Or Errors To Our Repo Or Discord Server. "
prompt3 = "You Can Disable Updating In The Config File"
prompt4 = "Join Our Discord: https://discord.gg/xrdjxyuSQt "
prompt5 = "Ok! Ill Ask Later...."
prompt6 = " Not Working Sites..."

download1 = "Downloading "
updates = "Updates Are Enabled!"


idk1 = "Not Sure What You Meant...."
idk2 = "Not Sure What You Meant. Ill Ask Later"
idk3 = "Not Sure.... But You Can Check Here: "
scan1 = "searching for sites with: "

status1 = "Working...."
status2 = "Creating / Overwriting Save File."
status3 = "Reinstalling............"
status4 = "Returning To Alfred Soon..."
status5 = "Testing....."
status6 = "Stopping..... Saved To captured/working.txt"
status7 = "Stopping........"

save1 = "Saved Results To"
save2 = "Saved Results To File"

error1 = "Permission Error"
error2 = "Type Error"
error3 = "Cant Find The Save File!"
error4 = "Directory doesn't exist."
error5 = "Cant Find Necessary Files. Trying To Reinstall Alfred"
error6 = "Uh Oh Error! Looks Like The Connection Dont Seem To Be Working. Check your connection Or Proxy, Then Try Again :"
error7 = "Cant Find Site File"
error8 = "Error Downloading Web Content!"
error9 = "Error With Site File"
error10 = "Invalid webdriver selection."
error11 = "An error occurred: "

fileshare1 = "[*] Listening as"
fileshare2 = "is connected."
fileshare3 = "Receiving"

wikiOption1 = "[1] Installation"
wikiOption2 = "[2] Options"
wikiOption3 = "[3] Errors"
wikiOption4 = "[4] Dark Alfred"
wikiOption5 = "[5] Modules"

wikilist = "You Can Find Info On It Here: "

rqUname = "Requested Username: "

sender1 = "[+] Connecting to"
sender2 = "[+] Connected."
sender3 = "Sending."
sender4 = "File To Send: ⤷ "

fs1 = "Host Server? [Y/N]: ⤷ "
fs2 = "Waiting To Connect To Host!"
fs3 = "Waiting For Client To Connect!"

siteDl1 = "Total script files in the page:"
siteDl2 = "Total CSS files in the page:"
# example bc imma forget
# import messages

# print(messages.title)  # Output: Hello, World!
# print(messages.text1)  # Output: This is a sample message.

# # Example of using placeholders in messages
# filename = "example.txt"
# print(messages.file_not_found.format(filename=filename))

==> alfred_osint-0.2.3.1-py3-none-any.whl: alfred_osint/lang/en.py <==
# en.py
# English

encrypt1 = "Encrypting Key..."

title1 = "Many Thanks To Our Partners!"

disclamer = "     Desclaimer: Not All Sites And Or Proxys Are Garineteed To Work! \n     By Using You Take Full Account Of Your Actions"

targetusernames = "The Target Username(s): "

version = "Version"

config1 = "Config File Exsits "
config2 = "Update File Exsits "
config3 = "Folder Already Exsists: "
config4 = "Check For Updates? [Y/n]: ⤷ "
config5 = "Edit The Config? [Y/n]: ⤷ "
config6 = "What Do You Want To Change? ⤷ "
config7 = "Creating folder: "
config8 = "Folder already exists: "

configOption1 = "[1] Check for updates: "
configOption2 = "[2] Show tips: "
configOption3 = "[3] Site Download Path: "
configOption4 = "[4] Browser: "
configOption5 = "[5] Language: "
configOptionA = "[A] Clean Up Alfred. (This Removes Temporary Files)"
configOptionB = "[B] Developer Tools."

configOption1Message = "Ok! [checkforupdates] Is Set For Yes. Changing To No"
configOption2Message = "Ok! [showtips] Is Set For Yes. Changing To No"
configOption3Message = "New Path: ⤷ "
configOption4Message = """Types Supported:
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            please enter your language code
            language Supported:
                it = Italian
                en = English
                il = Hebrew
                es = Spanish
                fr = French
                ar = Arabic
                de = German
                         """
configOptionAMessage = "Done!"
configOptionBMessage = "Welcome To The Developer Menu!"

configOption1Message2 = "Ok! [checkforupdates] Is Set For No. Changing To Yes"
configOption2Message2 = "Ok! [showtips] Is Set For No. Changing To Yes"
configOptionBMessage2 = "DONT Give The Following Keys To Anyone But A Alfred Developer."
configOptionBMessage3 = "privatekey: "
configOptionBMessage4 = "syscrypt: "

target = "Target: ⤷ "
browser = "Browser: "

file_not_found = "File not found: {filename}"
permission_denied = "Permission denied for {operation} on {path}"

note = "Note! "
path = "PATH: ⤷ "
warning1 = "Sites Many Not Allow Downloading Their Site Files. Use At Your Own Risk."
warning2 = " Using The Webscraper Is Pretty Slow."
warning3 = " This Is Your First Launch :D You Might Need To Restart Alfred To Use All The Modules"
warning4 = " You Are Using A Prerelease Of Alfred!"

confirm1 = "Want To Download Images/Videos? [Y/n] ⤷ "
confirm2 = "Run Again?: [Y/n] ⤷ "

prompt1 = "Enter Site Again: ⤷ "
prompt2 = "Kindly Report Any Bugs Or Errors To Our Repo Or Discord Server. "
prompt3 = "You Can Disable Updating In The Config File"
prompt4 = "Join Our Discord: https://discord.gg/xrdjxyuSQt "
prompt5 = "Ok! Ill Ask Later...."
prompt6 = " Not Working Sites..."

download1 = "Downloading "
updates = "Updates Are Enabled!"


idk1 = "Not Sure What You Meant...."
idk2 = "Not Sure What You Meant. Ill Ask Later"
idk3 = "Not Sure.... But You Can Check Here: "
scan1 = "searching for sites with: "

status1 = "Working...."
status2 = "Creating / Overwriting Save File."
status3 = "Reinstalling............"
status4 = "Returning To Alfred Soon..."
status5 = "Testing....."
status6 = "Stopping..... Saved To captured/working.txt"
status7 = "Stopping........"

save1 = "Saved Results To"
save2 = "Saved Results To File"

error1 = "Permission Error"
error2 = "Type Error"
error3 = "Cant Find The Save File!"
error4 = "Directory doesn't exist."
error5 = "Cant Find Necessary Files. Trying To Reinstall Alfred"
error6 = "Uh Oh Error! Looks Like The Connection Dont Seem To Be Working. Check your connection Or Proxy, Then Try Again :"
error7 = "Cant Find Site File"
error8 = "Error Downloading Web Content!"
error9 = "Error With Site File"
error10 = "Invalid webdriver selection."
error11 = "An error occurred: "

fileshare1 = "[*] Listening as"
fileshare2 = "is connected."
fileshare3 = "Receiving"

wikiOption1 = "[1] Installation"
wikiOption2 = "[2] Options"
wikiOption3 = "[3] Errors"
wikiOption4 = "[4] Dark Alfred"
wikiOption5 = "[5] Modules"

wikilist = "You Can Find Info On It Here: "

rqUname = "Requested Username: "

sender1 = "[+] Connecting to"
sender2 = "[+] Connected."
sender3 = "Sending."
sender4 = "File To Send: ⤷ "

fs1 = "Host Server? [Y/N]: ⤷ "
fs2 = "Waiting To Connect To Host!"
fs3 = "Waiting For Client To Connect!"

siteDl1 = "Total script files in the page:"
siteDl2 = "Total CSS files in the page:"
# example bc imma forget
# import messages

# print(messages.title)  # Output: Hello, World!
# print(messages.text1)  # Output: This is a sample message.

# # Example of using placeholders in messages
# filename = "example.txt"
# print(messages.file_not_found.format(filename=filename))
